# Regression.fit api

Last updated: 2023-07-12

This package (rfit - regression.fit) is for use at The George Washington University Data Science program. There are some useful and convenient functions we use in our python classes. 

One of them is dfapi, which connects to the api.regression.fit endpoint, to load dataframes used in our classes.
